# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: voltha_protos/afrouter.proto

from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from voltha_protos import common_pb2 as voltha__protos_dot_common__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='voltha_protos/afrouter.proto',
  package='afrouter',
  syntax='proto3',
  serialized_options=b'\n\023org.opencord.volthaZ0github.com/opencord/voltha-protos/v3/go/afrouter',
  serialized_pb=b'\n\x1cvoltha_protos/afrouter.proto\x12\x08\x61\x66router\x1a\x1avoltha_protos/common.proto\"6\n\x06Result\x12\x0f\n\x07success\x18\x01 \x01(\x08\x12\r\n\x05\x65rror\x18\x02 \x01(\t\x12\x0c\n\x04info\x18\x03 \x01(\t\"\x07\n\x05\x45mpty\"\x16\n\x05\x43ount\x12\r\n\x05\x63ount\x18\x01 \x01(\r\"\x82\x01\n\x04\x43onn\x12\x0e\n\x06server\x18\x01 \x01(\t\x12\x0b\n\x03pkg\x18\x02 \x01(\t\x12\x0b\n\x03svc\x18\x03 \x01(\t\x12\x0f\n\x07\x63luster\x18\x04 \x01(\t\x12\x0f\n\x07\x62\x61\x63kend\x18\x05 \x01(\t\x12\x12\n\nconnection\x18\x06 \x01(\t\x12\x0c\n\x04\x61\x64\x64r\x18\x07 \x01(\t\x12\x0c\n\x04port\x18\x08 \x01(\x04\"W\n\x08\x41\x66\x66inity\x12\x0e\n\x06router\x18\x01 \x01(\t\x12\r\n\x05route\x18\x02 \x01(\t\x12\x0f\n\x07\x63luster\x18\x03 \x01(\t\x12\x0f\n\x07\x62\x61\x63kend\x18\x04 \x01(\t\x12\n\n\x02id\x18\x05 \x01(\t2\xb4\x01\n\rConfiguration\x12\x33\n\rSetConnection\x12\x0e.afrouter.Conn\x1a\x10.afrouter.Result\"\x00\x12\x35\n\x0bSetAffinity\x12\x12.afrouter.Affinity\x1a\x10.afrouter.Result\"\x00\x12\x37\n\x11GetGoroutineCount\x12\x0f.afrouter.Empty\x1a\x0f.afrouter.Count\"\x00\x42G\n\x13org.opencord.volthaZ0github.com/opencord/voltha-protos/v3/go/afrouterb\x06proto3'
  ,
  dependencies=[voltha__protos_dot_common__pb2.DESCRIPTOR,])




_RESULT = _descriptor.Descriptor(
  name='Result',
  full_name='afrouter.Result',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='success', full_name='afrouter.Result.success', index=0,
      number=1, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='error', full_name='afrouter.Result.error', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='info', full_name='afrouter.Result.info', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=70,
  serialized_end=124,
)


_EMPTY = _descriptor.Descriptor(
  name='Empty',
  full_name='afrouter.Empty',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=126,
  serialized_end=133,
)


_COUNT = _descriptor.Descriptor(
  name='Count',
  full_name='afrouter.Count',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='count', full_name='afrouter.Count.count', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=135,
  serialized_end=157,
)


_CONN = _descriptor.Descriptor(
  name='Conn',
  full_name='afrouter.Conn',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='server', full_name='afrouter.Conn.server', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='pkg', full_name='afrouter.Conn.pkg', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='svc', full_name='afrouter.Conn.svc', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='cluster', full_name='afrouter.Conn.cluster', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='backend', full_name='afrouter.Conn.backend', index=4,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='connection', full_name='afrouter.Conn.connection', index=5,
      number=6, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='addr', full_name='afrouter.Conn.addr', index=6,
      number=7, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='port', full_name='afrouter.Conn.port', index=7,
      number=8, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=160,
  serialized_end=290,
)


_AFFINITY = _descriptor.Descriptor(
  name='Affinity',
  full_name='afrouter.Affinity',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='router', full_name='afrouter.Affinity.router', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='route', full_name='afrouter.Affinity.route', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='cluster', full_name='afrouter.Affinity.cluster', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='backend', full_name='afrouter.Affinity.backend', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='id', full_name='afrouter.Affinity.id', index=4,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=292,
  serialized_end=379,
)

DESCRIPTOR.message_types_by_name['Result'] = _RESULT
DESCRIPTOR.message_types_by_name['Empty'] = _EMPTY
DESCRIPTOR.message_types_by_name['Count'] = _COUNT
DESCRIPTOR.message_types_by_name['Conn'] = _CONN
DESCRIPTOR.message_types_by_name['Affinity'] = _AFFINITY
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

Result = _reflection.GeneratedProtocolMessageType('Result', (_message.Message,), {
  'DESCRIPTOR' : _RESULT,
  '__module__' : 'voltha_protos.afrouter_pb2'
  # @@protoc_insertion_point(class_scope:afrouter.Result)
  })
_sym_db.RegisterMessage(Result)

Empty = _reflection.GeneratedProtocolMessageType('Empty', (_message.Message,), {
  'DESCRIPTOR' : _EMPTY,
  '__module__' : 'voltha_protos.afrouter_pb2'
  # @@protoc_insertion_point(class_scope:afrouter.Empty)
  })
_sym_db.RegisterMessage(Empty)

Count = _reflection.GeneratedProtocolMessageType('Count', (_message.Message,), {
  'DESCRIPTOR' : _COUNT,
  '__module__' : 'voltha_protos.afrouter_pb2'
  # @@protoc_insertion_point(class_scope:afrouter.Count)
  })
_sym_db.RegisterMessage(Count)

Conn = _reflection.GeneratedProtocolMessageType('Conn', (_message.Message,), {
  'DESCRIPTOR' : _CONN,
  '__module__' : 'voltha_protos.afrouter_pb2'
  # @@protoc_insertion_point(class_scope:afrouter.Conn)
  })
_sym_db.RegisterMessage(Conn)

Affinity = _reflection.GeneratedProtocolMessageType('Affinity', (_message.Message,), {
  'DESCRIPTOR' : _AFFINITY,
  '__module__' : 'voltha_protos.afrouter_pb2'
  # @@protoc_insertion_point(class_scope:afrouter.Affinity)
  })
_sym_db.RegisterMessage(Affinity)


DESCRIPTOR._options = None

_CONFIGURATION = _descriptor.ServiceDescriptor(
  name='Configuration',
  full_name='afrouter.Configuration',
  file=DESCRIPTOR,
  index=0,
  serialized_options=None,
  serialized_start=382,
  serialized_end=562,
  methods=[
  _descriptor.MethodDescriptor(
    name='SetConnection',
    full_name='afrouter.Configuration.SetConnection',
    index=0,
    containing_service=None,
    input_type=_CONN,
    output_type=_RESULT,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='SetAffinity',
    full_name='afrouter.Configuration.SetAffinity',
    index=1,
    containing_service=None,
    input_type=_AFFINITY,
    output_type=_RESULT,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='GetGoroutineCount',
    full_name='afrouter.Configuration.GetGoroutineCount',
    index=2,
    containing_service=None,
    input_type=_EMPTY,
    output_type=_COUNT,
    serialized_options=None,
  ),
])
_sym_db.RegisterServiceDescriptor(_CONFIGURATION)

DESCRIPTOR.services_by_name['Configuration'] = _CONFIGURATION

# @@protoc_insertion_point(module_scope)
